//---------------------------------------------------------------------------

#include <vcl.h>
#pragma hdrstop

#include "Global2.h"
#include "BarRemsDlgs2.h"
#include "BarEditDlgs.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TBarRemsDlg2 *BarRemsDlg2;
//---------------------------------------------------------------------------

bool __fastcall ManageBarredRemailers2(TQSStatsWin4 *Owner, const AnsiString &FileName)
{
   BarRemsDlg2 = new TBarRemsDlg2(Owner, FileName);
   StrToFont(Owner->DlgsFontStr, BarRemsDlg2->Font);
   StrToFont(Owner->WinsFontStr, BarRemsDlg2->ListView->Font);
   BarRemsDlg2->ListView->Color = Owner->WindowColor;
   BarRemsDlg2->ShowModal();

   bool modified = BarRemsDlg2->Modified;
   delete BarRemsDlg2;
   return modified;
}

//---------------------------------------------------------------------------

__fastcall TBarRemsDlg2::TBarRemsDlg2(TComponent* Owner)
        : TForm(Owner)
{
}
//---------------------------------------------------------------------------

__fastcall TBarRemsDlg2::TBarRemsDlg2(TComponent* Owner, const AnsiString &FileName)
        : TForm(Owner)
{
   assert(Owner != NULL && FileName != "");

   BarFile = FileName;

   BarredLast = new TStringList();
   BarredRemailers = new TStringList();

   if (FileExists(BarFile))
      BarredRemailers->LoadFromFile(BarFile);

   OrgBars = BarredRemailers->Text;

   int i = 0; while (i < BarredRemailers->Count)
   {
      AnsiString remailer = BarredRemailers->Strings[i];

      if (GetTok(1, remailer, ',').Trim().LowerCase() == "last")
      {
         BarredLast->Add(GetTok(0, remailer, ','));
         BarredRemailers->Delete(i);
         continue;
      }

      i++;
   }

   Modified = false;
   ListView->Checkboxes = true;

   LoadListView();
}
//---------------------------------------------------------------------------

__fastcall TBarRemsDlg2::~TBarRemsDlg2()
{
   delete BarredRemailers;
   delete BarredLast;
}
//---------------------------------------------------------------------------

void __fastcall TBarRemsDlg2::LoadListView()
{
   AnsiString rem;
   TStringList *rems = new TStringList();
   rems->Duplicates = dupIgnore;
   rems->Sorted = true;

   if (ListView->Items->Count)
   {
      ListView->Items->Clear();
      Snooze(200);
   }

   GetMixmasterRemailers(rems);
   rems->AddStrings(BarredRemailers);

   for (int i = 0; i < BarredLast->Count; i++)
   {
      AnsiString bar = BarredLast->Strings[i];
      rems->Add(bar);

      rems->Sorted = false;
      int idx = rems->IndexOf(bar);
      rems->Strings[idx] = bar + ",last";
      rems->Sorted = true;
   }

   for (int i = 0; i < rems->Count; i++)
   {
      rem = rems->Strings[i];
      TListItem *item = ListView->Items->Add();
      item->Caption = rem;

      rem = GetTok(0, rem, ',');
      item->Checked = BarredRemailers->IndexOf(rem) >= 0 || BarredLast->IndexOf(rem) >= 0;
   }

   delete rems;
}
//---------------------------------------------------------------------------

void __fastcall TBarRemsDlg2::GetMixmasterRemailers(TStrings *mixers)
{
   assert(mixers != NULL);

   AnsiString line, remailer, name;
   mixers->Clear();

   TStringList *mlist = new TStringList();
   AnsiString mlisttxt = MixDir() + "mlist.txt";
   if (FileExists(mlisttxt)) mlist->LoadFromFile(mlisttxt);

   for (int i = 0; i < mlist->Count; i++)
   {
      line = mlist->Strings[i];
      if (line.Pos("%") > 0)
      {
         mixers->Add(GetTok(0, line, ' '));
      }
   }

   delete mlist;
}
//---------------------------------------------------------------------------
void __fastcall TBarRemsDlg2::ListViewAdvancedCustomDrawItem(
      TCustomListView *Sender, TListItem *Item, TCustomDrawState State,
      TCustomDrawStage Stage, bool &DefaultDraw)
{
   if (Item->Checked && Item->Caption.Pos(",last") == 0)
      ListView->Canvas->Font->Style = TFontStyles() << fsStrikeOut;
   else
      ListView->Canvas->Font->Style = TFontStyles();

   DefaultDraw = true;
}
//---------------------------------------------------------------------------
void __fastcall TBarRemsDlg2::FormCloseQuery(TObject *Sender,
      bool &CanClose)
{
   GetBarredFromListView(BarredRemailers);

   if (BarredRemailers->Text != OrgBars && ModalResult == mrOk)
   {
      if (MsgBox(this,
         "Newly barred remailers will have their entries removed from the corresponding stats    \n"
         "page when the Stats Window closes. This will occur even if you have downloaded    \n"
         "pages and choose not to save them. Keys are not removed. Stats entries are    \n"
         "sufficient to bar remailers.", mtInformation, MB_OKCANCEL) == IDCANCEL)
      {
         CanClose = false;
         return;
      }

      BarredRemailers->SaveToFile(BarFile);
      Modified = true;
   }
}
//---------------------------------------------------------------------------

void __fastcall TBarRemsDlg2::GetBarredFromListView(TStrings *Barred)
{
   Barred->Clear();
   for (int i = 0; i < ListView->Items->Count; i++)
   {
      TListItem *item = ListView->Items->Item[i];
      if (item->Checked)
         Barred->Add(item->Caption);
   }
}
//---------------------------------------------------------------------------

void __fastcall TBarRemsDlg2::EditSrcBtnClick(TObject *Sender)
{
   TStringList *bars = new TStringList();
   GetBarredFromListView(bars);

   if (EditBarredSource(this, bars))
   {
      BarredLast->Clear();
      BarredRemailers->Clear();
      for (int i = 0; i < bars->Count; i++)
      {
         AnsiString bar = bars->Strings[i];

         if (bar.Pos(",") == 0) BarredRemailers->Add(bar);
         else BarredLast->Add(GetTok(0, bar, ',').Trim());
      }
      LoadListView();
   }
}
//---------------------------------------------------------------------------


void __fastcall TBarRemsDlg2::PopupMenuPopup(TObject *Sender)
{
   TListItem *item = ListView->Selected;
   PopBarLastItem->Enabled = item != NULL;
   if (item)
   {
      AnsiString rem = item->Caption, name = GetTok(0, rem, ',');

      if (rem.Pos(",last") == 0)
         PopBarLastItem->Caption = "&Bar " + name + " from last";
      else
         PopBarLastItem->Caption = "Un&bar " + name;
   }
}
//---------------------------------------------------------------------------

void __fastcall TBarRemsDlg2::PopBarLastItemClick(TObject *Sender)
{
   TListItem *item = ListView->Selected;
   assert(item != NULL);

   AnsiString rem = item->Caption;
   if (rem.Pos(",last") > 0)
   {
      AnsiString name = GetTok(0, rem, ',');
      BarredRemailers->Add(name);
      BarredLast->Delete(BarredLast->IndexOf(name));
      item->Caption = name;
      item->Checked = false;
   }
   else
   {
      int idx = BarredRemailers->IndexOf(rem);
      if (idx >= 0)
         BarredRemailers->Delete(idx);
      BarredLast->Add(rem);
      item->Caption = rem + ",last";
      item->Checked = true;
   }
}
//---------------------------------------------------------------------------

void __fastcall TBarRemsDlg2::ListViewMouseDown(TObject *Sender,
      TMouseButton Button, TShiftState Shift, int X, int Y)
{
   TListItem *item = ListView->GetItemAt(X, Y);
   if (item != NULL)
   {
      item->Selected = true;
      if (!item->Checked && item->Caption.Pos(",") > 0)
         item->Caption = GetTok(0, item->Caption, ',').Trim();
   }
}
//---------------------------------------------------------------------------

