//---------------------------------------------------------------------------

#include <vcl.h>
#pragma hdrstop

#include "global2.h"
#include "RearrangeDlgs.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TReorderDlg *ReorderDlg;
//---------------------------------------------------------------------------

bool __fastcall ReorderURLSources(TQSStatsWin4 *Owner, const AnsiString &URLFileName)
{
   ReorderDlg = new TReorderDlg(Owner, URLFileName);
   ReorderDlg->SourceList->Color = Owner->WindowColor;
   StrToFont(Owner->WinsFontStr, ReorderDlg->SourceList->Font);
   StrToFont(Owner->DlgsFontStr, ReorderDlg->Font);
   ReorderDlg->ShowModal();

   bool ok = ReorderDlg->ModalResult == mrOk;
   delete ReorderDlg;
   return ok;
}

//---------------------------------------------------------------------------
// TReorderDlg
//---------------------------------------------------------------------------

__fastcall TReorderDlg::TReorderDlg(TComponent* Owner)
        : TForm(Owner)
{
}
//---------------------------------------------------------------------------

__fastcall TReorderDlg::TReorderDlg(TComponent* Owner, const AnsiString &URLFileName)
        : TForm(Owner)
{
   assert(Owner != NULL && URLFileName != "");

   FileName = URLFileName;
   TStringList *lines = new TStringList();
   if (FileExists(URLFileName)) lines->LoadFromFile(URLFileName);
   for (int i = 0; i < lines->Count; i++)
   {
      AnsiString line = lines->Strings[i];
      if (line.Pos("[") == 1 && line != "[quicksilver]")
         SourceList->Items->Add(line.SubString(2, line.Length() - 2));
   }
   delete lines;

   modified = false;
}
//---------------------------------------------------------------------------
#pragma argsused
void __fastcall TReorderDlg::FormCloseQuery(TObject *Sender, bool &CanClose)
{
   if (modified)
   {
      if (ModalResult == mrCancel)
      {
         switch(MsgBox(this, "The source order is changed. Save your changes?",
            mtConfirmation, MB_YESNOCANCEL))
         {
            case IDCANCEL: CanClose = false;
            case IDNO: return;
         }
      }
      Save();
   }
}
//---------------------------------------------------------------------------
#pragma argsused
void __fastcall TReorderDlg::SourceListClick(TObject *Sender)
{
   if (SourceList->ItemIndex >= 0)
   {
      DownBtn->Enabled = true;
      UpBtn->Enabled = true;
   }
}
//---------------------------------------------------------------------------
#pragma argsused
void __fastcall TReorderDlg::UpBtnClick(TObject *Sender)
{
   int index = SourceList->ItemIndex;
   TStrings *items = SourceList->Items;
   if (index < 0) return;

   if (index > 0)
   {
      items->Move(index, index - 1);
      modified = true;
   }
   else MessageBeep(MB_ICONHAND);

   //ActiveControl = SourceList;
   SourceList->ItemIndex = index - 1;
}
//---------------------------------------------------------------------------
#pragma argsused
void __fastcall TReorderDlg::DownBtnClick(TObject *Sender)
{
   int index = SourceList->ItemIndex;
   TStrings *items = SourceList->Items;
   if (index < 0) return;

   if (index < items->Count - 1)
   {
      items->Move(index, index + 1);
      modified = true;
   }
   else MessageBeep(MB_ICONHAND);

   //ActiveControl = SourceList;
   SourceList->ItemIndex = index + 1;
   modified = true;
}
//---------------------------------------------------------------------------

void __fastcall TReorderDlg::GetURLs(const AnsiString &Source, TStrings *URLs)
{
   URLs->Clear();
   bool saving = false;
   TStringList *lines = new TStringList();
   if (FileExists(FileName)) lines->LoadFromFile(FileName);
   for (int i = 0; i < lines->Count; i++)
   {
      AnsiString line = lines->Strings[i].Trim();
      if (saving)
      {
         if (line.IsEmpty() || line[1] == '[')
            break;

         URLs->Add(line);
      }
      if (line == "[" + Source + "]")
         saving = true;
   }
   delete lines;
}
//---------------------------------------------------------------------------

void __fastcall TReorderDlg::Save()
{
   TStringList *urls = new TStringList();
   TStringList *newlist = new TStringList();
   for (int i = 0; i < SourceList->Items->Count; i++)
   {
      AnsiString source = SourceList->Items->Strings[i];

      GetURLs(source, urls);
      newlist->Add("[" + source + "]");
      newlist->AddStrings(urls);
      newlist->Add("");
   }

   GetURLs(QuikSource, urls);
   newlist->Add("[" + QuikSource + "]");
   newlist->AddStrings(urls);

   newlist->SaveToFile(FileName);
   delete newlist;
   delete urls;
}
//---------------------------------------------------------------------------

