//---------------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop
#include <clipbrd.hpp>

#include "Global2.h"
#include "URLDlgs.h"
#include "HTTPmods2.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TURLDlg *URLDlg;
//---------------------------------------------------------------------------

bool __fastcall OpenURLManager(TQSStatsWin4 *Owner, const AnsiString &FileName,
   TStrings *Proxy)
{
   assert(Owner != NULL && FileName != "");

   if (SecureModeMsg(Owner))
      return false;

   URLDlg = new TURLDlg(Owner);
   StrToFont(Owner->DlgsFontStr, URLDlg->Font);
   StrToFont(Owner->EditFontStr, URLDlg->Editor->Font);
   URLDlg->Editor->Color = Owner->WindowColor;
   if (FileExists(FileName)) URLDlg->LoadFile(FileName);
   URLDlg->Proxy = Proxy;

   URLDlg->ShowModal();
   bool ok = URLDlg->ModalResult == mrOk;
   delete URLDlg;
   return ok;
}
//---------------------------------------------------------------------------

__fastcall TURLDlg::TURLDlg(TComponent* Owner)
        : TForm(Owner)
{
   OrgPage = new TStringList();
   Editor->Clear();
}
//---------------------------------------------------------------------------

__fastcall TURLDlg::~TURLDlg()
{
   delete OrgPage;
}
//---------------------------------------------------------------------------

void __fastcall TURLDlg::LoadFile(const AnsiString &Filename)
{
   assert(Filename != "");

   Editor->Clear();
   FileName = Filename;
   if (FileExists(FileName))
      Editor->Lines->LoadFromFile(FileName);
}
//---------------------------------------------------------------------------

void __fastcall TURLDlg::FormCloseQuery(TObject *, bool &CanClose)
{
   if (Editor->Modified && !ViewBogus)
   {
      if (ModalResult == mrCancel)
      {
         switch (MsgBox(this, "Your URLs are modified. Save your changes?    ",
            MT_CONFIRM, MB_YESNOCANCEL))
         {
            case IDCANCEL: CanClose = false;
            case IDNO: return;
         }
      }
//**************************************
      if (SecureModeMsg(this))
      {
         CanClose = false;
         return;
      }
//**************************************
      Save();
   }
}
//---------------------------------------------------------------------------

void __fastcall TURLDlg::Save()
{
   Global->DB->PutPageDateStr("urls.txt", ModifiedDate);
   Editor->Lines->SaveToFile(FileName);
}
//---------------------------------------------------------------------------

void __fastcall TURLDlg::RefreshBtnClick(TObject *)
{
   if (Working)
   {
      Cancel = true;
      return;
   }

   AnsiString proxy;
   if (Proxy)
      proxy = Proxy->Values["name"];
   if (proxy.IsEmpty())
      proxy = "none";

   if (MsgBox(this,
     "Shall I go online and fetch urls.txt?     \nProxy: " + proxy,
      MT_CONFIRM, MB_OKCANCEL) == IDOK)
         Refresh();
}
//---------------------------------------------------------------------------

void __fastcall TURLDlg::DisplayNewPage(TStrings *Page)
{
   Editor->Clear();
   Snooze(500);
   Editor->Lines->AddStrings(Page);
}
//---------------------------------------------------------------------------

bool __fastcall TURLDlg::Refresh()
{
   Cancel = false;
   AnsiString URL;

   for (int i = 0; i < Editor->Lines->Count; i++)
   {
      AnsiString line = Editor->Lines->Strings[i].LowerCase();
      if (line.Pos("urls.txt ") == 1)
      {
         URL = GetTokSpc(1, line);
      }
   }

   if (URL.IsEmpty())
   {
      MsgBox(this,
        "I can't find the URL (urls.txt) for downloading a fresh URL page!      \n"
        "It should be listed in the QuickSilver section of the URL list you\n"
        "are looking at.",
      MT_ERROR, MB_OK);
      return false;
   }

   TStringList *page = new TStringList();

   AnsiString cap = RefreshBtn->Caption;
   RefreshBtn->Caption = "Cancel";
   ProgressBar->Show();

   Working = true;
   ModifiedDate = "";
   TDateTime datetime = 0;
   int result = HTTPGet(this, URL, page, ProgressBar, Proxy, &Cancel, 30, datetime);
   if (result == HTTP_OK)
      ModifiedDate = AnsiString((double)datetime);
   Working = false;

   ProgressBar->Hide();
   RefreshBtn->Caption = cap;

   if (Cancel || result == HTTP_TIMEOUT)
   {
      delete page;
      return false;
   }

   if (result != HTTP_OK)
   {
      MsgBox(this, page->Strings[0] + "    ", MT_ERROR, MB_OK);
      delete page;
      return false;
   }

   TrimNulls(page);
   assert(page->Count > 0);

   if (page->Strings[0].LowerCase() != "quicksilver urls")
   {
      MsgBox(this,
         "The new page doesn't look correct. The first line\n"
         "should be 'QuickSilver URLS'. I'll put this page in the    \n"
         "editor window for your viewing. Click Cancel to\n"
         "return to original page.",
      MT_INFO, MB_OK);

      OrgPage->Text = Editor->Lines->Text;
      OrgModified = Editor->Modified;
      OkBtn->Enabled = false;
      ViewBogus = true;
   }

   DisplayNewPage(page);

   delete page;
   return true;
}
//---------------------------------------------------------------------------

void __fastcall TURLDlg::CancelBtnClick(TObject *)
{
   if (ViewBogus)
   {
      DisplayNewPage(OrgPage);
      Editor->Modified = OrgModified;
      OkBtn->Enabled = true;
      ViewBogus = false;
      OrgPage->Clear();
      return;
   }
   ModalResult = mrCancel;
}
//---------------------------------------------------------------------------

